/*******************************************************************************
* File Name: InputCounter.c
* Version 1.0
*
* Description:
*  This file provides the source code to the API for the InputCounter
*  component
*
********************************************************************************
* Copyright 2016-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "InputCounter.h"

/** Indicates whether or not the InputCounter has been initialized. 
*  The variable is initialized to 0 and set to 1 the first time 
*  InputCounter_Start() is called. This allows the Component to 
*  restart without reinitialization after the first call to 
*  the InputCounter_Start() routine.
*/
uint8_t InputCounter_initVar = 0U;

/** The instance-specific configuration structure. This should be used in the 
*  associated InputCounter_Init() function.
*/ 
cy_stc_tcpwm_counter_config_t const InputCounter_config =
{
        .period = 16777213UL,
        .clockPrescaler = 0UL,
        .runMode = 0UL,
        .countDirection = 0UL,
        .compareOrCapture = 2UL,
        .compare0 = 16777213UL,
        .compare1 = 16384UL,
        .enableCompareSwap = false,
        .interruptSources = 0UL,
        .captureInputMode = 1UL,
        .captureInput = CY_TCPWM_INPUT_CREATOR,
        .reloadInputMode = 0UL,
        .reloadInput = CY_TCPWM_INPUT_CREATOR,
        .startInputMode = 0UL,
        .startInput = CY_TCPWM_INPUT_CREATOR,
        .stopInputMode = 1UL,
        .stopInput = CY_TCPWM_INPUT_CREATOR,
        .countInputMode = 0UL,
        .countInput = CY_TCPWM_INPUT_CREATOR,
};


/*******************************************************************************
* Function Name: InputCounter_Start
****************************************************************************//**
*
*  Calls the InputCounter_Init() when called the first time and enables 
*  the InputCounter. For subsequent calls the configuration is left 
*  unchanged and the component is just enabled.
*
* \globalvars
*  \ref InputCounter_initVar
*
*******************************************************************************/
void InputCounter_Start(void)
{
    if (0U == InputCounter_initVar)
    {
        (void)Cy_TCPWM_Counter_Init(InputCounter_HW, InputCounter_CNT_NUM, &InputCounter_config); 

        InputCounter_initVar = 1U;
    }

    Cy_TCPWM_Enable_Multiple(InputCounter_HW, InputCounter_CNT_MASK);
    
    #if (InputCounter_INPUT_DISABLED == 0UL)
        Cy_TCPWM_TriggerStart(InputCounter_HW, InputCounter_CNT_MASK);
    #endif /* (InputCounter_INPUT_DISABLED == 0UL) */    
}


/* [] END OF FILE */
