/*******************************************************************************
* File Name: InputCounter.h
* Version 1.0
*
* Description:
*  This file provides constants and parameter values for the InputCounter
*  component.
*
********************************************************************************
* Copyright 2016-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(InputCounter_CY_TCPWM_COUNTER_PDL_H)
#define InputCounter_CY_TCPWM_COUNTER_PDL_H

#include "cyfitter.h"
#include "tcpwm/cy_tcpwm_counter.h"

   
/*******************************************************************************
* Variables
*******************************************************************************/
/**
* \addtogroup group_globals
* @{
*/
extern uint8_t  InputCounter_initVar;
extern cy_stc_tcpwm_counter_config_t const InputCounter_config;
/** @} group_globals */


/***************************************
*  Conditional Compilation Parameters
***************************************/

#define InputCounter_INIT_COMPARE_OR_CAPTURE    (2UL)


/***************************************
*        Function Prototypes
****************************************/
/**
* \addtogroup group_general
* @{
*/
void InputCounter_Start(void);
__STATIC_INLINE cy_en_tcpwm_status_t InputCounter_Init(cy_stc_tcpwm_counter_config_t const *config);
__STATIC_INLINE void InputCounter_DeInit(void);
__STATIC_INLINE void InputCounter_Enable(void);
__STATIC_INLINE void InputCounter_Disable(void);
__STATIC_INLINE uint32_t InputCounter_GetStatus(void);

#if(CY_TCPWM_COUNTER_MODE_CAPTURE == InputCounter_INIT_COMPARE_OR_CAPTURE)
    __STATIC_INLINE uint32_t InputCounter_GetCapture(void);
    __STATIC_INLINE uint32_t InputCounter_GetCaptureBuf(void);
#else
    __STATIC_INLINE void InputCounter_SetCompare0(uint32_t compare0);
    __STATIC_INLINE uint32_t InputCounter_GetCompare0(void);
    __STATIC_INLINE void InputCounter_SetCompare1(uint32_t compare1);
    __STATIC_INLINE uint32_t InputCounter_GetCompare1(void);
    __STATIC_INLINE void InputCounter_EnableCompareSwap(bool enable);
#endif /* (CY_TCPWM_COUNTER_MODE_CAPTURE == InputCounter_INIT_COMPARE_OR_CAPTURE) */

__STATIC_INLINE void InputCounter_SetCounter(uint32_t count);
__STATIC_INLINE uint32_t InputCounter_GetCounter(void);
__STATIC_INLINE void InputCounter_SetPeriod(uint32_t period);
__STATIC_INLINE uint32_t InputCounter_GetPeriod(void);
__STATIC_INLINE void InputCounter_TriggerStart(void);
__STATIC_INLINE void InputCounter_TriggerReload(void);
__STATIC_INLINE void InputCounter_TriggerStop(void);
__STATIC_INLINE void InputCounter_TriggerCapture(void);
__STATIC_INLINE uint32_t InputCounter_GetInterruptStatus(void);
__STATIC_INLINE void InputCounter_ClearInterrupt(uint32_t source);
__STATIC_INLINE void InputCounter_SetInterrupt(uint32_t source);
__STATIC_INLINE void InputCounter_SetInterruptMask(uint32_t mask);
__STATIC_INLINE uint32_t InputCounter_GetInterruptMask(void);
__STATIC_INLINE uint32_t InputCounter_GetInterruptStatusMasked(void);
/** @} general */


/***************************************
*           API Constants
***************************************/

/**
* \addtogroup group_macros
* @{
*/
/** This is a ptr to the base address of the TCPWM instance */
#define InputCounter_HW                 (InputCounter_TCPWM__HW)

/** This is a ptr to the base address of the TCPWM CNT instance */
#define InputCounter_CNT_HW             (InputCounter_TCPWM__CNT_HW)

/** This is the counter instance number in the selected TCPWM */
#define InputCounter_CNT_NUM            (InputCounter_TCPWM__CNT_IDX)

/** This is the bit field representing the counter instance in the selected TCPWM */
#define InputCounter_CNT_MASK           (1UL << InputCounter_CNT_NUM)
/** @} group_macros */

#define InputCounter_INPUT_MODE_MASK    (0x3U)
#define InputCounter_INPUT_DISABLED     (7U)


/*******************************************************************************
* Function Name: InputCounter_Init
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Counter_Init() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE cy_en_tcpwm_status_t InputCounter_Init(cy_stc_tcpwm_counter_config_t const *config)
{
    return(Cy_TCPWM_Counter_Init(InputCounter_HW, InputCounter_CNT_NUM, config));
}


/*******************************************************************************
* Function Name: InputCounter_DeInit
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Counter_DeInit() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void InputCounter_DeInit(void)                   
{
    Cy_TCPWM_Counter_DeInit(InputCounter_HW, InputCounter_CNT_NUM, &InputCounter_config);
}

/*******************************************************************************
* Function Name: InputCounter_Enable
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Enable_Multiple() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void InputCounter_Enable(void)                   
{
    Cy_TCPWM_Enable_Multiple(InputCounter_HW, InputCounter_CNT_MASK);
}


/*******************************************************************************
* Function Name: InputCounter_Disable
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Disable_Multiple() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void InputCounter_Disable(void)                  
{
    Cy_TCPWM_Disable_Multiple(InputCounter_HW, InputCounter_CNT_MASK);
}


/*******************************************************************************
* Function Name: InputCounter_GetStatus
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Counter_GetStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t InputCounter_GetStatus(void)                
{
    return(Cy_TCPWM_Counter_GetStatus(InputCounter_HW, InputCounter_CNT_NUM));
}


#if(CY_TCPWM_COUNTER_MODE_CAPTURE == InputCounter_INIT_COMPARE_OR_CAPTURE)
    /*******************************************************************************
    * Function Name: InputCounter_GetCapture
    ****************************************************************************//**
    *
    * Invokes the Cy_TCPWM_Counter_GetCapture() PDL driver function.
    *
    *******************************************************************************/
    __STATIC_INLINE uint32_t InputCounter_GetCapture(void)               
    {
        return(Cy_TCPWM_Counter_GetCapture(InputCounter_HW, InputCounter_CNT_NUM));
    }


    /*******************************************************************************
    * Function Name: InputCounter_GetCaptureBuf
    ****************************************************************************//**
    *
    * Invokes the Cy_TCPWM_Counter_GetCaptureBuf() PDL driver function.
    *
    *******************************************************************************/
    __STATIC_INLINE uint32_t InputCounter_GetCaptureBuf(void)            
    {
        return(Cy_TCPWM_Counter_GetCaptureBuf(InputCounter_HW, InputCounter_CNT_NUM));
    }
#else
    /*******************************************************************************
    * Function Name: InputCounter_SetCompare0
    ****************************************************************************//**
    *
    * Invokes the Cy_TCPWM_Counter_SetCompare0() PDL driver function.
    *
    *******************************************************************************/
    __STATIC_INLINE void InputCounter_SetCompare0(uint32_t compare0)      
    {
        Cy_TCPWM_Counter_SetCompare0(InputCounter_HW, InputCounter_CNT_NUM, compare0);
    }


    /*******************************************************************************
    * Function Name: InputCounter_GetCompare0
    ****************************************************************************//**
    *
    * Invokes the Cy_TCPWM_Counter_GetCompare0() PDL driver function.
    *
    *******************************************************************************/
    __STATIC_INLINE uint32_t InputCounter_GetCompare0(void)              
    {
        return(Cy_TCPWM_Counter_GetCompare0(InputCounter_HW, InputCounter_CNT_NUM));
    }


    /*******************************************************************************
    * Function Name: InputCounter_SetCompare1
    ****************************************************************************//**
    *
    * Invokes the Cy_TCPWM_Counter_SetCompare1() PDL driver function.
    *
    *******************************************************************************/
    __STATIC_INLINE void InputCounter_SetCompare1(uint32_t compare1)      
    {
        Cy_TCPWM_Counter_SetCompare1(InputCounter_HW, InputCounter_CNT_NUM, compare1);
    }


    /*******************************************************************************
    * Function Name: InputCounter_GetCompare1
    ****************************************************************************//**
    *
    * Invokes the Cy_TCPWM_Counter_GetCompare1() PDL driver function.
    *
    *******************************************************************************/
    __STATIC_INLINE uint32_t InputCounter_GetCompare1(void)              
    {
        return(Cy_TCPWM_Counter_GetCompare1(InputCounter_HW, InputCounter_CNT_NUM));
    }


    /*******************************************************************************
    * Function Name: InputCounter_EnableCompareSwap
    ****************************************************************************//**
    *
    * Invokes the Cy_TCPWM_Counter_EnableCompareSwap() PDL driver function.
    *
    *******************************************************************************/
    __STATIC_INLINE void InputCounter_EnableCompareSwap(bool enable)  
    {
        Cy_TCPWM_Counter_EnableCompareSwap(InputCounter_HW, InputCounter_CNT_NUM, enable);
    }
#endif /* (CY_TCPWM_COUNTER_MODE_CAPTURE == InputCounter_INIT_COMPARE_OR_CAPTURE) */


/*******************************************************************************
* Function Name: InputCounter_SetCounter
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Counter_SetCounter() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void InputCounter_SetCounter(uint32_t count)          
{
    Cy_TCPWM_Counter_SetCounter(InputCounter_HW, InputCounter_CNT_NUM, count);
}


/*******************************************************************************
* Function Name: InputCounter_GetCounter
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Counter_GetCounter() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t InputCounter_GetCounter(void)               
{
    return(Cy_TCPWM_Counter_GetCounter(InputCounter_HW, InputCounter_CNT_NUM));
}


/*******************************************************************************
* Function Name: InputCounter_SetPeriod
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Counter_SetPeriod() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void InputCounter_SetPeriod(uint32_t period)          
{
    Cy_TCPWM_Counter_SetPeriod(InputCounter_HW, InputCounter_CNT_NUM, period);
}


/*******************************************************************************
* Function Name: InputCounter_GetPeriod
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Counter_GetPeriod() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t InputCounter_GetPeriod(void)                
{
    return(Cy_TCPWM_Counter_GetPeriod(InputCounter_HW, InputCounter_CNT_NUM));
}


/*******************************************************************************
* Function Name: InputCounter_TriggerStart
****************************************************************************//**
*
* Invokes the Cy_TCPWM_TriggerStart() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void InputCounter_TriggerStart(void)             
{
    Cy_TCPWM_TriggerStart(InputCounter_HW, InputCounter_CNT_MASK);
}


/*******************************************************************************
* Function Name: InputCounter_TriggerReload
****************************************************************************//**
*
* Invokes the Cy_TCPWM_TriggerReloadOrIndex() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void InputCounter_TriggerReload(void)     
{
    Cy_TCPWM_TriggerReloadOrIndex(InputCounter_HW, InputCounter_CNT_MASK);
}


/*******************************************************************************
* Function Name: InputCounter_TriggerStop
****************************************************************************//**
*
* Invokes the Cy_TCPWM_TriggerStopOrKill() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void InputCounter_TriggerStop(void)
{
    Cy_TCPWM_TriggerStopOrKill(InputCounter_HW, InputCounter_CNT_MASK);
}


/*******************************************************************************
* Function Name: InputCounter_TriggerCapture
****************************************************************************//**
*
* Invokes the Cy_TCPWM_TriggerCaptureOrSwap() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void InputCounter_TriggerCapture(void)     
{
    Cy_TCPWM_TriggerCaptureOrSwap(InputCounter_HW, InputCounter_CNT_MASK);
}


/*******************************************************************************
* Function Name: InputCounter_GetInterruptStatus
****************************************************************************//**
*
* Invokes the Cy_TCPWM_GetInterruptStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t InputCounter_GetInterruptStatus(void)       
{
    return(Cy_TCPWM_GetInterruptStatus(InputCounter_HW, InputCounter_CNT_NUM));
}


/*******************************************************************************
* Function Name: InputCounter_ClearInterrupt
****************************************************************************//**
*
* Invokes the Cy_TCPWM_ClearInterrupt() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void InputCounter_ClearInterrupt(uint32_t source)     
{
    Cy_TCPWM_ClearInterrupt(InputCounter_HW, InputCounter_CNT_NUM, source);
}


/*******************************************************************************
* Function Name: InputCounter_SetInterrupt
****************************************************************************//**
*
* Invokes the Cy_TCPWM_SetInterrupt() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void InputCounter_SetInterrupt(uint32_t source)
{
    Cy_TCPWM_SetInterrupt(InputCounter_HW, InputCounter_CNT_NUM, source);
}


/*******************************************************************************
* Function Name: InputCounter_SetInterruptMask
****************************************************************************//**
*
* Invokes the Cy_TCPWM_SetInterruptMask() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void InputCounter_SetInterruptMask(uint32_t mask)     
{
    Cy_TCPWM_SetInterruptMask(InputCounter_HW, InputCounter_CNT_NUM, mask);
}


/*******************************************************************************
* Function Name: InputCounter_GetInterruptMask
****************************************************************************//**
*
* Invokes the Cy_TCPWM_GetInterruptMask() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t InputCounter_GetInterruptMask(void)         
{
    return(Cy_TCPWM_GetInterruptMask(InputCounter_HW, InputCounter_CNT_NUM));
}


/*******************************************************************************
* Function Name: InputCounter_GetInterruptStatusMasked
****************************************************************************//**
*
* Invokes the Cy_TCPWM_GetInterruptStatusMasked() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t InputCounter_GetInterruptStatusMasked(void)
{
    return(Cy_TCPWM_GetInterruptStatusMasked(InputCounter_HW, InputCounter_CNT_NUM));
}

#endif /* InputCounter_CY_TCPWM_COUNTER_PDL_H */


/* [] END OF FILE */
