/*******************************************************************************
* File Name: RefCounter.c
* Version 1.0
*
* Description:
*  This file provides the source code to the API for the RefCounter
*  component
*
********************************************************************************
* Copyright 2016-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "RefCounter.h"

/** Indicates whether or not the RefCounter has been initialized. 
*  The variable is initialized to 0 and set to 1 the first time 
*  RefCounter_Start() is called. This allows the Component to 
*  restart without reinitialization after the first call to 
*  the RefCounter_Start() routine.
*/
uint8_t RefCounter_initVar = 0U;

/** The instance-specific configuration structure. This should be used in the 
*  associated RefCounter_Init() function.
*/ 
cy_stc_tcpwm_counter_config_t const RefCounter_config =
{
        .period = 16777213UL,
        .clockPrescaler = 0UL,
        .runMode = 0UL,
        .countDirection = 0UL,
        .compareOrCapture = 2UL,
        .compare0 = 16777213UL,
        .compare1 = 16384UL,
        .enableCompareSwap = false,
        .interruptSources = 0UL,
        .captureInputMode = 1UL,
        .captureInput = CY_TCPWM_INPUT_CREATOR,
        .reloadInputMode = 0UL,
        .reloadInput = CY_TCPWM_INPUT_CREATOR,
        .startInputMode = 0UL,
        .startInput = CY_TCPWM_INPUT_CREATOR,
        .stopInputMode = 1UL,
        .stopInput = CY_TCPWM_INPUT_CREATOR,
        .countInputMode = 0UL,
        .countInput = CY_TCPWM_INPUT_CREATOR,
};


/*******************************************************************************
* Function Name: RefCounter_Start
****************************************************************************//**
*
*  Calls the RefCounter_Init() when called the first time and enables 
*  the RefCounter. For subsequent calls the configuration is left 
*  unchanged and the component is just enabled.
*
* \globalvars
*  \ref RefCounter_initVar
*
*******************************************************************************/
void RefCounter_Start(void)
{
    if (0U == RefCounter_initVar)
    {
        (void)Cy_TCPWM_Counter_Init(RefCounter_HW, RefCounter_CNT_NUM, &RefCounter_config); 

        RefCounter_initVar = 1U;
    }

    Cy_TCPWM_Enable_Multiple(RefCounter_HW, RefCounter_CNT_MASK);
    
    #if (RefCounter_INPUT_DISABLED == 0UL)
        Cy_TCPWM_TriggerStart(RefCounter_HW, RefCounter_CNT_MASK);
    #endif /* (RefCounter_INPUT_DISABLED == 0UL) */    
}


/* [] END OF FILE */
