/*******************************************************************************
* File Name: RefCounter.h
* Version 1.0
*
* Description:
*  This file provides constants and parameter values for the RefCounter
*  component.
*
********************************************************************************
* Copyright 2016-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(RefCounter_CY_TCPWM_COUNTER_PDL_H)
#define RefCounter_CY_TCPWM_COUNTER_PDL_H

#include "cyfitter.h"
#include "tcpwm/cy_tcpwm_counter.h"

   
/*******************************************************************************
* Variables
*******************************************************************************/
/**
* \addtogroup group_globals
* @{
*/
extern uint8_t  RefCounter_initVar;
extern cy_stc_tcpwm_counter_config_t const RefCounter_config;
/** @} group_globals */


/***************************************
*  Conditional Compilation Parameters
***************************************/

#define RefCounter_INIT_COMPARE_OR_CAPTURE    (2UL)


/***************************************
*        Function Prototypes
****************************************/
/**
* \addtogroup group_general
* @{
*/
void RefCounter_Start(void);
__STATIC_INLINE cy_en_tcpwm_status_t RefCounter_Init(cy_stc_tcpwm_counter_config_t const *config);
__STATIC_INLINE void RefCounter_DeInit(void);
__STATIC_INLINE void RefCounter_Enable(void);
__STATIC_INLINE void RefCounter_Disable(void);
__STATIC_INLINE uint32_t RefCounter_GetStatus(void);

#if(CY_TCPWM_COUNTER_MODE_CAPTURE == RefCounter_INIT_COMPARE_OR_CAPTURE)
    __STATIC_INLINE uint32_t RefCounter_GetCapture(void);
    __STATIC_INLINE uint32_t RefCounter_GetCaptureBuf(void);
#else
    __STATIC_INLINE void RefCounter_SetCompare0(uint32_t compare0);
    __STATIC_INLINE uint32_t RefCounter_GetCompare0(void);
    __STATIC_INLINE void RefCounter_SetCompare1(uint32_t compare1);
    __STATIC_INLINE uint32_t RefCounter_GetCompare1(void);
    __STATIC_INLINE void RefCounter_EnableCompareSwap(bool enable);
#endif /* (CY_TCPWM_COUNTER_MODE_CAPTURE == RefCounter_INIT_COMPARE_OR_CAPTURE) */

__STATIC_INLINE void RefCounter_SetCounter(uint32_t count);
__STATIC_INLINE uint32_t RefCounter_GetCounter(void);
__STATIC_INLINE void RefCounter_SetPeriod(uint32_t period);
__STATIC_INLINE uint32_t RefCounter_GetPeriod(void);
__STATIC_INLINE void RefCounter_TriggerStart(void);
__STATIC_INLINE void RefCounter_TriggerReload(void);
__STATIC_INLINE void RefCounter_TriggerStop(void);
__STATIC_INLINE void RefCounter_TriggerCapture(void);
__STATIC_INLINE uint32_t RefCounter_GetInterruptStatus(void);
__STATIC_INLINE void RefCounter_ClearInterrupt(uint32_t source);
__STATIC_INLINE void RefCounter_SetInterrupt(uint32_t source);
__STATIC_INLINE void RefCounter_SetInterruptMask(uint32_t mask);
__STATIC_INLINE uint32_t RefCounter_GetInterruptMask(void);
__STATIC_INLINE uint32_t RefCounter_GetInterruptStatusMasked(void);
/** @} general */


/***************************************
*           API Constants
***************************************/

/**
* \addtogroup group_macros
* @{
*/
/** This is a ptr to the base address of the TCPWM instance */
#define RefCounter_HW                 (RefCounter_TCPWM__HW)

/** This is a ptr to the base address of the TCPWM CNT instance */
#define RefCounter_CNT_HW             (RefCounter_TCPWM__CNT_HW)

/** This is the counter instance number in the selected TCPWM */
#define RefCounter_CNT_NUM            (RefCounter_TCPWM__CNT_IDX)

/** This is the bit field representing the counter instance in the selected TCPWM */
#define RefCounter_CNT_MASK           (1UL << RefCounter_CNT_NUM)
/** @} group_macros */

#define RefCounter_INPUT_MODE_MASK    (0x3U)
#define RefCounter_INPUT_DISABLED     (7U)


/*******************************************************************************
* Function Name: RefCounter_Init
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Counter_Init() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE cy_en_tcpwm_status_t RefCounter_Init(cy_stc_tcpwm_counter_config_t const *config)
{
    return(Cy_TCPWM_Counter_Init(RefCounter_HW, RefCounter_CNT_NUM, config));
}


/*******************************************************************************
* Function Name: RefCounter_DeInit
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Counter_DeInit() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void RefCounter_DeInit(void)                   
{
    Cy_TCPWM_Counter_DeInit(RefCounter_HW, RefCounter_CNT_NUM, &RefCounter_config);
}

/*******************************************************************************
* Function Name: RefCounter_Enable
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Enable_Multiple() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void RefCounter_Enable(void)                   
{
    Cy_TCPWM_Enable_Multiple(RefCounter_HW, RefCounter_CNT_MASK);
}


/*******************************************************************************
* Function Name: RefCounter_Disable
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Disable_Multiple() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void RefCounter_Disable(void)                  
{
    Cy_TCPWM_Disable_Multiple(RefCounter_HW, RefCounter_CNT_MASK);
}


/*******************************************************************************
* Function Name: RefCounter_GetStatus
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Counter_GetStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t RefCounter_GetStatus(void)                
{
    return(Cy_TCPWM_Counter_GetStatus(RefCounter_HW, RefCounter_CNT_NUM));
}


#if(CY_TCPWM_COUNTER_MODE_CAPTURE == RefCounter_INIT_COMPARE_OR_CAPTURE)
    /*******************************************************************************
    * Function Name: RefCounter_GetCapture
    ****************************************************************************//**
    *
    * Invokes the Cy_TCPWM_Counter_GetCapture() PDL driver function.
    *
    *******************************************************************************/
    __STATIC_INLINE uint32_t RefCounter_GetCapture(void)               
    {
        return(Cy_TCPWM_Counter_GetCapture(RefCounter_HW, RefCounter_CNT_NUM));
    }


    /*******************************************************************************
    * Function Name: RefCounter_GetCaptureBuf
    ****************************************************************************//**
    *
    * Invokes the Cy_TCPWM_Counter_GetCaptureBuf() PDL driver function.
    *
    *******************************************************************************/
    __STATIC_INLINE uint32_t RefCounter_GetCaptureBuf(void)            
    {
        return(Cy_TCPWM_Counter_GetCaptureBuf(RefCounter_HW, RefCounter_CNT_NUM));
    }
#else
    /*******************************************************************************
    * Function Name: RefCounter_SetCompare0
    ****************************************************************************//**
    *
    * Invokes the Cy_TCPWM_Counter_SetCompare0() PDL driver function.
    *
    *******************************************************************************/
    __STATIC_INLINE void RefCounter_SetCompare0(uint32_t compare0)      
    {
        Cy_TCPWM_Counter_SetCompare0(RefCounter_HW, RefCounter_CNT_NUM, compare0);
    }


    /*******************************************************************************
    * Function Name: RefCounter_GetCompare0
    ****************************************************************************//**
    *
    * Invokes the Cy_TCPWM_Counter_GetCompare0() PDL driver function.
    *
    *******************************************************************************/
    __STATIC_INLINE uint32_t RefCounter_GetCompare0(void)              
    {
        return(Cy_TCPWM_Counter_GetCompare0(RefCounter_HW, RefCounter_CNT_NUM));
    }


    /*******************************************************************************
    * Function Name: RefCounter_SetCompare1
    ****************************************************************************//**
    *
    * Invokes the Cy_TCPWM_Counter_SetCompare1() PDL driver function.
    *
    *******************************************************************************/
    __STATIC_INLINE void RefCounter_SetCompare1(uint32_t compare1)      
    {
        Cy_TCPWM_Counter_SetCompare1(RefCounter_HW, RefCounter_CNT_NUM, compare1);
    }


    /*******************************************************************************
    * Function Name: RefCounter_GetCompare1
    ****************************************************************************//**
    *
    * Invokes the Cy_TCPWM_Counter_GetCompare1() PDL driver function.
    *
    *******************************************************************************/
    __STATIC_INLINE uint32_t RefCounter_GetCompare1(void)              
    {
        return(Cy_TCPWM_Counter_GetCompare1(RefCounter_HW, RefCounter_CNT_NUM));
    }


    /*******************************************************************************
    * Function Name: RefCounter_EnableCompareSwap
    ****************************************************************************//**
    *
    * Invokes the Cy_TCPWM_Counter_EnableCompareSwap() PDL driver function.
    *
    *******************************************************************************/
    __STATIC_INLINE void RefCounter_EnableCompareSwap(bool enable)  
    {
        Cy_TCPWM_Counter_EnableCompareSwap(RefCounter_HW, RefCounter_CNT_NUM, enable);
    }
#endif /* (CY_TCPWM_COUNTER_MODE_CAPTURE == RefCounter_INIT_COMPARE_OR_CAPTURE) */


/*******************************************************************************
* Function Name: RefCounter_SetCounter
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Counter_SetCounter() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void RefCounter_SetCounter(uint32_t count)          
{
    Cy_TCPWM_Counter_SetCounter(RefCounter_HW, RefCounter_CNT_NUM, count);
}


/*******************************************************************************
* Function Name: RefCounter_GetCounter
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Counter_GetCounter() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t RefCounter_GetCounter(void)               
{
    return(Cy_TCPWM_Counter_GetCounter(RefCounter_HW, RefCounter_CNT_NUM));
}


/*******************************************************************************
* Function Name: RefCounter_SetPeriod
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Counter_SetPeriod() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void RefCounter_SetPeriod(uint32_t period)          
{
    Cy_TCPWM_Counter_SetPeriod(RefCounter_HW, RefCounter_CNT_NUM, period);
}


/*******************************************************************************
* Function Name: RefCounter_GetPeriod
****************************************************************************//**
*
* Invokes the Cy_TCPWM_Counter_GetPeriod() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t RefCounter_GetPeriod(void)                
{
    return(Cy_TCPWM_Counter_GetPeriod(RefCounter_HW, RefCounter_CNT_NUM));
}


/*******************************************************************************
* Function Name: RefCounter_TriggerStart
****************************************************************************//**
*
* Invokes the Cy_TCPWM_TriggerStart() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void RefCounter_TriggerStart(void)             
{
    Cy_TCPWM_TriggerStart(RefCounter_HW, RefCounter_CNT_MASK);
}


/*******************************************************************************
* Function Name: RefCounter_TriggerReload
****************************************************************************//**
*
* Invokes the Cy_TCPWM_TriggerReloadOrIndex() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void RefCounter_TriggerReload(void)     
{
    Cy_TCPWM_TriggerReloadOrIndex(RefCounter_HW, RefCounter_CNT_MASK);
}


/*******************************************************************************
* Function Name: RefCounter_TriggerStop
****************************************************************************//**
*
* Invokes the Cy_TCPWM_TriggerStopOrKill() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void RefCounter_TriggerStop(void)
{
    Cy_TCPWM_TriggerStopOrKill(RefCounter_HW, RefCounter_CNT_MASK);
}


/*******************************************************************************
* Function Name: RefCounter_TriggerCapture
****************************************************************************//**
*
* Invokes the Cy_TCPWM_TriggerCaptureOrSwap() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void RefCounter_TriggerCapture(void)     
{
    Cy_TCPWM_TriggerCaptureOrSwap(RefCounter_HW, RefCounter_CNT_MASK);
}


/*******************************************************************************
* Function Name: RefCounter_GetInterruptStatus
****************************************************************************//**
*
* Invokes the Cy_TCPWM_GetInterruptStatus() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t RefCounter_GetInterruptStatus(void)       
{
    return(Cy_TCPWM_GetInterruptStatus(RefCounter_HW, RefCounter_CNT_NUM));
}


/*******************************************************************************
* Function Name: RefCounter_ClearInterrupt
****************************************************************************//**
*
* Invokes the Cy_TCPWM_ClearInterrupt() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void RefCounter_ClearInterrupt(uint32_t source)     
{
    Cy_TCPWM_ClearInterrupt(RefCounter_HW, RefCounter_CNT_NUM, source);
}


/*******************************************************************************
* Function Name: RefCounter_SetInterrupt
****************************************************************************//**
*
* Invokes the Cy_TCPWM_SetInterrupt() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void RefCounter_SetInterrupt(uint32_t source)
{
    Cy_TCPWM_SetInterrupt(RefCounter_HW, RefCounter_CNT_NUM, source);
}


/*******************************************************************************
* Function Name: RefCounter_SetInterruptMask
****************************************************************************//**
*
* Invokes the Cy_TCPWM_SetInterruptMask() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE void RefCounter_SetInterruptMask(uint32_t mask)     
{
    Cy_TCPWM_SetInterruptMask(RefCounter_HW, RefCounter_CNT_NUM, mask);
}


/*******************************************************************************
* Function Name: RefCounter_GetInterruptMask
****************************************************************************//**
*
* Invokes the Cy_TCPWM_GetInterruptMask() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t RefCounter_GetInterruptMask(void)         
{
    return(Cy_TCPWM_GetInterruptMask(RefCounter_HW, RefCounter_CNT_NUM));
}


/*******************************************************************************
* Function Name: RefCounter_GetInterruptStatusMasked
****************************************************************************//**
*
* Invokes the Cy_TCPWM_GetInterruptStatusMasked() PDL driver function.
*
*******************************************************************************/
__STATIC_INLINE uint32_t RefCounter_GetInterruptStatusMasked(void)
{
    return(Cy_TCPWM_GetInterruptStatusMasked(RefCounter_HW, RefCounter_CNT_NUM));
}

#endif /* RefCounter_CY_TCPWM_COUNTER_PDL_H */


/* [] END OF FILE */
