/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "common.h"
#include "project.h"
#include "display.h"
#include "bitmap.h"

#include "stdlib.h" 
#include "stdio.h" 

volatile uint8_t status=0;

/*******************************************************************************
* Function Name: HandleError
****************************************************************************//**
*
* Placeholder function for handling IPC and other errors. Does nothing -
* implements halt on error.
*  
*******************************************************************************/
void HandleError(void)
{
    static uint8_t i;
    /* for now, just halt on error */
    while(1)
    {
        i++;
    }
}

void input_stop()
{
    NVIC_ClearPendingIRQ(isr_InputStop_cfg.intrSrc);
	status=STATUS_STOP;
}

void input_overflow()
{
    NVIC_ClearPendingIRQ(isr_InputOverflow_cfg.intrSrc);
	status=STATUS_INPUT_OVERFLOW;
}

void ref_overflow()
{
    NVIC_ClearPendingIRQ(isr_RefOverflow_cfg.intrSrc);
	status=STATUS_REF_OVERFLOW;
}

int count=0;

int main()
{
    __enable_irq(); /* Enable global interrupts. */

    Control_Reg_Start_Write(0);
	Control_Reg_Mux_Write(1);
	
	Comp_Input_Start();

    Cy_SysInt_Init(&isr_InputOverflow_cfg, input_overflow); 
    NVIC_ClearPendingIRQ(isr_InputOverflow_cfg.intrSrc);
    NVIC_EnableIRQ((IRQn_Type)isr_InputOverflow_cfg.intrSrc);
	
    Cy_SysInt_Init(&isr_RefOverflow_cfg, ref_overflow); 
    NVIC_ClearPendingIRQ(isr_RefOverflow_cfg.intrSrc);
    NVIC_EnableIRQ((IRQn_Type)isr_RefOverflow_cfg.intrSrc);

    Cy_SysInt_Init(&isr_InputStop_cfg, input_stop); 
    NVIC_ClearPendingIRQ(isr_InputStop_cfg.intrSrc);
    NVIC_EnableIRQ((IRQn_Type)isr_InputStop_cfg.intrSrc);

	InputCounter_Start();
	RefCounter_Start();

    Cy_TCPWM_Counter_SetCounter(RefCounter_HW, RefCounter_CNT_NUM, 0);
    Cy_TCPWM_Counter_SetCounter(InputCounter_HW, InputCounter_CNT_NUM, 0);

    unsigned long count=0;
	
    NOKIA_Init();
    
    NOKIA_Contrast(0x45);
    
    NOKIA_Goto(0,0);
    NOKIA_Clear();
    NOKIA_Str("startup", Middle_Font);
    NOKIA_Goto(0,3);

	char buffer[14];
    
    for(;;)
    {
        // start measurenent
        status=0;
		Control_Reg_Start_Write(1);
		CyDelay(1);
        NVIC_ClearPendingIRQ(isr_InputOverflow_cfg.intrSrc);
        NVIC_ClearPendingIRQ(isr_RefOverflow_cfg.intrSrc);
        NVIC_ClearPendingIRQ(isr_InputStop_cfg.intrSrc);
        status=0;
		Control_Reg_Start_Write(0);
		
        // wait until we get a status from one of the ISRs
		while (0==status){};

        CyDelay(1);

        // read the results
		unsigned long ref_count=Cy_TCPWM_Counter_GetCapture(RefCounter_HW, RefCounter_CNT_NUM);
		unsigned long in_count=Cy_TCPWM_Counter_GetCapture(InputCounter_HW, InputCounter_CNT_NUM);

		unsigned long ref_value=Cy_TCPWM_Counter_GetCounter(RefCounter_HW, RefCounter_CNT_NUM);
		unsigned long in_value=Cy_TCPWM_Counter_GetCounter(InputCounter_HW, InputCounter_CNT_NUM);

        if (STATUS_STOP==status)
		{
            NOKIA_Goto(0,0);
            NOKIA_Clear();
			double freq;
            
			// actual counter value of ref counter is period + current value
			freq=((double)in_count)*((double)REF_FREQ)/((double)ref_count+REF_PERIOD);
            int decimals=7;
            unsigned long f=(uint32_t)freq;
            while (f>=10)
            {
                f=f/10;
                decimals--;
            }
            if (decimals<0)
            {
                decimals=0;
            }
            if (0==decimals)
            {
    			sprintf(buffer,"f=%lu",(unsigned long)freq);
            }
            else
            {
    			sprintf(buffer,"f=%.*f",decimals,freq);
            }
            NOKIA_Str(buffer, Middle_Font);
            NOKIA_Goto(0,2);
			sprintf(buffer,"r=%lu/%lu",ref_count,ref_value);
            NOKIA_Str(buffer, Middle_Font);
            NOKIA_Goto(0,3);
			sprintf(buffer,"i=%lu/%lu",in_count,in_value);
            NOKIA_Str(buffer, Middle_Font);
		}
		else if (STATUS_INPUT_OVERFLOW==status)
		{
            NOKIA_Goto(0,0);
            NOKIA_Clear();
            NOKIA_Goto(0,0);
            NOKIA_Str("freq too high", Middle_Font);
            NOKIA_Goto(0,2);
			sprintf(buffer,"r=%lu/%lu",ref_count,ref_value);
            NOKIA_Str(buffer, Middle_Font);
            NOKIA_Goto(0,3);
			sprintf(buffer,"i=%lu/%lu",in_count,in_value);
            NOKIA_Str(buffer, Middle_Font);
		}
		else if (STATUS_REF_OVERFLOW==status)
		{
            NOKIA_Goto(0,0);
            NOKIA_Clear();
            NOKIA_Goto(0,0);
            NOKIA_Str("freq too low", Middle_Font);
		}
        else
        {
            NOKIA_Goto(0,0);
            NOKIA_Clear();
            NOKIA_Goto(0,1);
            NOKIA_Str("N/A", Middle_Font);
        }            
        NOKIA_Goto(0,5);
		sprintf(buffer,"%7lu",count);
        NOKIA_Str(buffer, Middle_Font);
        count++;
    }
}
/* [] END OF FILE */
